@@ -29,13 +29,13 @@ class TransferDetails : public QWidget
         // gets the generic details widget if the transfer factory doesn't override it
         static QWidget *detailsWidget(TransferHandler *transfer);
         
-    public slots:
+    public Q_SLOTS:
         void slotTransferChanged(TransferHandler * transfer, TransferHandler::ChangesFlags flags);
         
     private:
-        TransferHandler * m_transfer;
-        QVBoxLayout     * m_layout;
-        QWidget         * m_genericWidget;
+        TransferHandler * m_transfer = nullptr;
+        QVBoxLayout     * m_layout = nullptr;
+        QWidget         * m_genericWidget = nullptr;
 
         Ui::TransferDetailsFrm frm;
 };
